@@ -6,7 +6,7 @@ function(model) {
 
 .vif <-
 function(x) {
-	v <- vcov(x)
+	v <- .vcov(x)
 	nam <- dimnames(v)[[1L]]
 	if(dim(v)[1L] < 2L) return(structure(rep_len(1, dim(v)[1L]),
 										 names = dimnames(v)[[1L]]))
@@ -30,26 +30,33 @@ function(x, sd, vif, n, p = length(x) - 1) {
 	sd * sqrt(1 / vif) * sqrt((n - 1) / (n - p))
 }
 
-partial.sd <- function(x) {
+partial.sd <-
+function(x) {
+	b <- coef(x)
 	mm <- model.matrix(x)
+	mm <- mm[, match(names(b), colnames(mm)), drop = FALSE]
+	colnames(mm) <- names(b)
 	m <- ncol(mm)
-	.partialsd(coef(x), apply(mm, 2L, sd), .vif(x), nobs(x),
+	.partialsd(b, apply(mm, 2L, sd), .vif(x), nobs(x),
 			   sum(attr(mm, "assign") != 0))
 }
 
 `std.coef` <-
 function(x, partial.sd, ...) {
-	#coefmat <- coefTable(x, ...)[, 1L:2L, drop = FALSE]
-	coefmat <- coefTable(x, ...)
+	#b <- coefTable(x, ...)[, 1L:2L, drop = FALSE]
+	b <- coefTable(x, ...)
 	mm <- model.matrix(x)
+	mm <- mm[, match(rownames(b), colnames(mm)), drop = FALSE]
+	colnames(mm) <- names(b)
+	#b <- b[colnames(mm), ]
 	if(partial.sd) {
-		bx <- .partialsd(coefmat[, 1L], apply(mm, 2L, sd),
+		bx <- .partialsd(b[, 1L], apply(mm, 2L, sd),
 				.vif(x), nobs(x), sum(attr(mm, "assign") != 0))
 	} else {
 		response.sd <- sd(model.response(model.frame(x)))
 		bx <- apply(mm, 2L, sd) / response.sd
 	}
-	coefmat[, 1L:2L] <- coefmat[, 1L:2L] * bx
-	colnames(coefmat)[1L:2L] <- c("Estimate*", "Std. Error*")
-	return (coefmat)
+	b[, 1L:2L] <- b[, 1L:2L] * bx
+	colnames(b)[1L:2L] <- c("Estimate*", "Std. Error*")
+	return(b)
 }
